venim.akatsuki package
======================

Submodules
----------

venim.akatsuki.ir2 module
-------------------------

.. automodule:: venim.akatsuki.ir2
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: venim.akatsuki
   :members:
   :undoc-members:
   :show-inheritance:
